<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 3, 2013 3:06:29 PM
 * @version $Rev$
 */

/**
 * Subscribe class
 * Used to ....
 */
class Entity_Form_Subscribe {
    private $interfacer = null;
    private $publication_id = 0;
	
    private $required_fields = array(
        'email', 'firstname', 'lastname', 'gender', 'functionLevel1'
    );

    public function __construct($publication_id = 0) {
        $this->interfacer = WP_Interfacer::getInstance();
        $this->publication_id = $publication_id;
    }

    public function display($params = array()) {
        $backtrace = debug_backtrace();
        foreach ($backtrace as $bkt) {
            if (isset($bkt['file'])) {
                if (basename($bkt['file']) == 'class-frontend.php') {
                    return '';
                }
            }
        }
        $data = array();
        $errors = array();
        $general_error = '';
        $captchaStatus = Environment_Settings::getJASCaptchaStatus();
        $input_data = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
        $labels = Utils_Labels::get();
        
        if ($input_data !== NULL && wp_verify_nonce($input_data['_carerix_nonce_field'], 'subscribe')) {
            foreach ($this->required_fields as $name) {
                if (isset($input_data[$name]) && strlen(trim($input_data[$name])) == 0) {
                    $errors[$name] = $labels['CxFinder.message.error.pageContent'];
                }
            }

            if ($captchaStatus == 'on' && strtolower($input_data['captcha_code']) !== strtolower($_SESSION['captcha']['code'])) {
                $errors['captcha'] = $labels['CxWpPlugin.message.captcha'];
            }

            if (count($errors) == 0) {
                $employee = new Carerix_Api_Rest_Entity_CREmployee();
                $employee->setEmailAddress($input_data['email']);
                $employee->setFirstName($input_data['firstname']);
                $employee->setLastName($input_data['lastname']);
                $employee->setLastNamePrefix($input_data['lastNamePrefix']);

                
                if (isset($input_data['gender'])) {
                    $gender = Carerix_Api_Rest_Entity_CRDataNode::find($input_data['gender']);
                    if ($gender) {
                        $employee->setToGenderNode($gender);
                    }
                }
                
                if (isset($input_data['functionLevel0'])) {
                    $functionLevel0 = Carerix_Api_Rest_Entity_CRDataNode::find($input_data['functionLevel0']);
                    if ($functionLevel0) {
                        $employee->setToProductTypeNode1($functionLevel0);
                    }
                }
                
                if (isset($input_data['functionLevel1'])) {
                    $functionLevel1 = Carerix_Api_Rest_Entity_CRDataNode::find($input_data['functionLevel1']);
                    if ($functionLevel1) {
                        $employee->setToLevel1Function1($functionLevel1);
                    }
                }
                
                if (isset($input_data['prefCountry1Node'])) {
                    $prefCountry1Node = Carerix_Api_Rest_Entity_CRDataNode::find($input_data['prefCountry1Node']);
                    if ($prefCountry1Node) {
                        $employee->setToPrefCountry1Node($prefCountry1Node);
                    }
                }
                if (isset($input_data['prefRegion1Node'])) {
                    $prefRegion1Node = Carerix_Api_Rest_Entity_CRDataNode::find($input_data['prefRegion1Node']);
                    if ($prefRegion1Node) {
                        $employee->setToPrefRegion1Node($prefRegion1Node);
                    }
                }


                $transientData = array('group' => 'JobAlertTag', 'frequency' => 'DailyTag');
                if (isset($params['groupid'])) {
                    $transientData['nid'] = $params['groupid'];
                }

                $employee->setTransient($transientData);

                $exception = false;
                try {
                    $employee->subscribe();
                    $data['succesful'] = true;
                } catch (Carerix_Api_Rest_Exception $care) {
                    $general_error = $care->getMessage();
                    $exception = $care;
                } catch (Exception $ex) {
                    $general_error = $ex->getMessage();
                    $exception = $ex;
                }
                if ($exception) {
                    Utils_Log::write(Utils_Log::TYPE_JAS, $employee, $exception);
                }
            }
        }

        $data['general_error'] = $general_error;
        $data['errors'] = $errors;

        $data['genders'] = $this->getGenders();
        $data['functionLevels'] = $this->getFunctionLevels();
        $data['countryRegions'] = $this->getCountryRegionNodes();

        $data['captcha'] = $captchaStatus;

        $template = new Utils_Template('frontend/forms/subscribe');
        ob_start();
        $template->with($data)->display();
        $output = ob_get_contents();
        ob_end_clean();
        echo $output;
    }

	private function getGenders()
	{
        $processedGenders = array();

        try {
			$genders = Carerix_Api_Rest_Entity_CRDataNode::listBy(array('type'=>'Salutation', 
                'show'=>array('value', 'dataNodeID', 'isHidden', 'parentNodes.value'), 'qualifier'=> " isHidden = 0 "));
			foreach($genders as $gender)
			{

                if(Environment_Settings::getFormGenderUnknown() !== 'on') {

                    $toContinue = false;
                    foreach($gender->parentNodes as $pn) {
                        if($pn->value == 'UnknownTag' ) $toContinue = true;
                    }
                    if($toContinue) continue;
                }
				$processedGenders[] = array('id'=>$gender->dataNodeID, 'value'=>$gender->value);
            }
			
		} catch (Exception $ex)
		{
            Utils_Log::write(Utils_Log::TYPE_DATANODE, $genders, $ex);
        }
        return $processedGenders;
    }

	private function getFunctionLevels()
	{
        $cache_session_key = md5('function_level_cache');
        if(FALSE !== $cached_data = Utils_Cache::get($cache_session_key)) return $cached_data;

        $general_exception = false;
        try {

			$fieldsLevel0 = Carerix_Api_Rest_Entity_CRDataNode::listBy(array('type'=>'Business line'));

            $fieldsHierarchy = array();


			foreach($fieldsLevel0 as $field)
			{

				$level = array('id'=>$field->dataNodeID, 'value'=>$field->value, 'children'=>array());
				$fieldsLevel1 = Carerix_Api_Rest_Entity_CRDataNode::listBy(array('type'=>'Function0', 'parent'=>$field->dataNodeID));

				if($fieldsLevel1 != null) {
					foreach($fieldsLevel1 as $fieldLevel1)
					{
						$level2 = array('id'=>$fieldLevel1->dataNodeID, 'value'=>$fieldLevel1->value, 'children'=>array());

						$fieldsLevel2 = Carerix_Api_Rest_Entity_CRDataNode::listBy(array('type'=>'Function1', 'parent'=>$fieldLevel1->dataNodeID));	

						if($fieldsLevel2 !== null) {
							foreach($fieldsLevel2 as $fieldLevel2)
							{
								$level3 = array('id'=>$fieldLevel2->dataNodeID, 'value'=>$fieldLevel2->value);
                                array_push($level2['children'], $level3);
                            }
                        }
                        array_push($level['children'], $level2);
                    }
                }

                array_push($fieldsHierarchy, $level);
            }
		}
		catch (Carerix_Api_Rest_Exception $care)
		{
            $general_exception = $care;
		} catch (Exception $ex)
		{
            $general_exception = $ex;
        }

        Utils_Cache::set($cache_session_key, $fieldsHierarchy);
		if($general_exception)
		{
            Utils_Log::write(Utils_Log::TYPE_DATANODE, false, $general_exception);
            return $fieldsHierarchy;
		} else 
		{
            Utils_Cache::set($cache_session_key, $fieldsHierarchy);
            return $fieldsHierarchy;
        }
    }

    /**
     * Returns list of Countries and Regions
     * @return array
     */
    private function getCountryRegionNodes() {
        $cache_session_key = md5('country_region_cache');
        if (FALSE !== $cached_data = Utils_Cache::get($cache_session_key)) {
            return $cached_data;
        }

        $general_exception = false;
        $result = array();
        try {
            $countries = Carerix_Api_Rest_Entity_CRDataNode::listBy(array(
                'type' => 'Country',
                'show' => array('value', 'childrenNodes.value'),
                'qualifier' => "isHidden = 0 and isActive = 1"
            ));

            foreach ($countries as $country) {
                $childrens = array();
                if (count($country->childrenNodes)) {
                    foreach ($country->childrenNodes as $child) {
                        $childrens[] = array('id' => $child->dataNodeID, 'value' => $child->value);
                    }
                }
                $result[] = array('id' => $country->dataNodeID, 'value' => $country->value, 'children' => $childrens);
            }
        } catch (Carerix_Api_Rest_Exception $care) {
            $general_exception = $care;
        } catch (Exception $ex) {
            $general_exception = $ex;
        }

        Utils_Cache::set($cache_session_key, $result);
        if ($general_exception) {
            Utils_Log::write(Utils_Log::TYPE_DATANODE, false, $general_exception);
            return $result;
        } else {
            Utils_Cache::set($cache_session_key, $result);
            return $result;
        }
    }

}
